getAllSeriesInfo: Information about data series

View source: R/CBRT.R

getAllSeriesInfoR Documentation

Information about data series

Description

Creates a meta data object for all data series

Usage

getAllSeriesInfo(CBRTKey = myCBRTKey, verbose = TRUE)

Arguments

CBRTKey

Your personal CBRT access key

verbose

TRUE turns on status and information messages to the console

Value

a data.table object

Examples

## Not run: 
allCBRTSeries <- getAllSeriesInfo()

## End(Not run)


CBRT documentation built on Feb. 18, 2026, 9:07 a.m.