- group
Code for the data group.
- CBRTKey
Your personal CBRT access key.
- freq
Numeric, the frequency of the data series. If not defined, the default
(the highest possible frequency) will be used. The frequencies are as follows:
- 1
Day
- 2
Work day
- 3
Week
- 4
Biweekly
- 5
Month
- 6
Quarter
- 7
Six months
- 8
Year
If a frequency level lower than the default is used, the data will be aggregated
by using the default method for that data group (for example, if monthly data
are download for weekly series).
startDate
The beginning date for data series (DD-MM-YYYY).
endDate
The ending date for data series (DD-MM-YYYY). If not defined, the default
(the latest available) will be used.
na.rm
Logical variable to drop all missing dates.
verbose
TRUE turns on status and information messages to the console.