searchCBRT: Variable search

View source: R/CBRT.R

searchCBRTR Documentation

Variable search

Description

Search for keywords in the CBRT datasets

Usage

searchCBRT(keywords, field = c("groups", "categories", "series"), tags = FALSE)

Arguments

keywords

A vector of keywords

field

The name of the field to be searched ("groups", "categories" or "series"). We recommend searching first the "groups" names.

tags

A logical variable that indicates if the tags to be searched

Value

a data.table object

Examples

searchCBRT(c("production", "labor", "labour"))
searchCBRT(c("production", "labor", "labour"), field = "series")
searchCBRT(c("production", "labor", "labour"), tags = TRUE)


CBRT documentation built on Feb. 18, 2026, 9:07 a.m.