Learn R Programming

CBRT (version 0.2.0)

getAllSeriesInfo: Information about data series

Description

Creates a meta data object for all data series

Usage

getAllSeriesInfo(CBRTKey = myCBRTKey, verbose = TRUE)

Value

a data.table object

Arguments

CBRTKey

Your personal CBRT access key

verbose

TRUE turns on status and information messages to the console

Examples

Run this code
if (FALSE) {
allCBRTSeries <- getAllSeriesInfo()
}

Run the code above in your browser using DataLab