powered by
Creates a meta data object for all data series
getAllSeriesInfo(CBRTKey = myCBRTKey, verbose = TRUE)
a data.table object
Your personal CBRT access key
TRUE turns on status and information messages to the console
if (FALSE) { allCBRTSeries <- getAllSeriesInfo() }
Run the code above in your browser using DataLab