Learn R Programming

CBRT (version 0.2.0)

searchCBRT: Variable search

Description

Search for keywords in the CBRT datasets

Usage

searchCBRT(keywords, field = c("groups", "categories", "series"), tags = FALSE)

Value

a data.table object

Arguments

keywords

A vector of keywords

field

The name of the field to be searched ("groups", "categories" or "series"). We recommend searching first the "groups" names.

tags

A logical variable that indicates if the tags to be searched

Examples

Run this code
searchCBRT(c("production", "labor", "labour"))
searchCBRT(c("production", "labor", "labour"), field = "series")
searchCBRT(c("production", "labor", "labour"), tags = TRUE)

Run the code above in your browser using DataLab