powered by
Search for keywords in the CBRT datasets
searchCBRT(keywords, field = c("groups", "categories", "series"), tags = FALSE)
a data.table object
A vector of keywords
The name of the field to be searched ("groups", "categories" or "series"). We recommend searching first the "groups" names.
A logical variable that indicates if the tags to be searched
searchCBRT(c("production", "labor", "labour")) searchCBRT(c("production", "labor", "labour"), field = "series") searchCBRT(c("production", "labor", "labour"), tags = TRUE)
Run the code above in your browser using DataLab